@@ -1,4 +1,7 @@
 from . import table
+from . import maths
+from . import word2tex
+
 import argparse
 
 
@@ -13,5 +16,6 @@ def excel2table():
     if args.type == None:
         args.type = "tex"
 
+    print(args[0])
     df = table.read_excel(args.excel)
     print(table.convert(df, typ=args.type))
